"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.build_args = exports.add_styled_string = exports.LEVEL_TO_COLOR_STYLE = exports.FONT_FAMILY_BETTER_MONOSPACE = exports.FONT_FAMILY_BETTER_PROPORTIONAL = void 0;
const FONT_FAMILY_BETTER_PROPORTIONAL = 'font-family: ' + [
    '-apple-system',
    'BlinkMacSystemFont',
    'noto',
    'roboto',
    'sans-serif',
].join(', ');
exports.FONT_FAMILY_BETTER_PROPORTIONAL = FONT_FAMILY_BETTER_PROPORTIONAL;
const FONT_FAMILY_BETTER_MONOSPACE = 'font-family: ' + [
    '"Fira Code"',
    'Menlo',
    'Consolas',
    'monospace',
].join(', ');
exports.FONT_FAMILY_BETTER_MONOSPACE = FONT_FAMILY_BETTER_MONOSPACE;
const LEVEL_TO_COLOR_STYLE = {
    // empty = no need, console method already covers it well
    fatal: '',
    emerg: '',
    alert: '',
    crit: '',
    error: '',
    warning: '',
    warn: '',
    notice: 'color: #659AD2',
    info: 'color: #659AD2',
    verbose: 'color: #659AD2',
    log: '',
    debug: 'color: #9AA2AA',
    trace: 'color: #9AA2AA',
    silly: 'color: #9AA2AA',
};
exports.LEVEL_TO_COLOR_STYLE = LEVEL_TO_COLOR_STYLE;
function add_styled_string(line, chunk, ...styles) {
    const [existing_chunks, ...existing_chunks_styles] = line;
    return [
        existing_chunks + '%c' + chunk,
        ...existing_chunks_styles,
        styles.join(';') + ';',
    ];
}
exports.add_styled_string = add_styled_string;
function build_args(line, payload) {
    const { err } = payload;
    let { details } = payload;
    const args = line;
    if (err) {
        // err will be passed as the LAST arg for reasons (see below)
        // however the "last arg" display doesn't allow examining the optional err properties
        // so we also add the err to the details:
        // (tested on FF/Chrome/Safari)
        details = {
            ...details,
            err,
        };
    }
    if (Object.keys(details).length)
        args.push(details);
    // err *as an arg* triggers a good display of the stacktrace
    // however it should be LAST because it takes a lot of room and "hides" further args
    // (tested on FF/Chrome/Safari)
    if (err)
        args.push(err);
    return args;
}
exports.build_args = build_args;
//# sourceMappingURL=common.js.map